<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'atto_teamsmeeting', language 'id', version '5.0'.
 *
 * @package     atto_teamsmeeting
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['addlink'] = 'Tambahkan tautan';
$string['createteamsmeeting'] = 'Buat rapat tim';
$string['gotomeeting'] = 'Pergi rapat';
$string['iframe_not_found'] = 'Rapat tidak ditemukan!';
$string['legacy_setting_warning'] = '<br/>
<span style="color:red">PERINGATAN: Aplikasi Rapat yang diterapkan di https://enovation.ie/msteams sudah tidak digunakan lagi dan akan segera dihapus. Aplikasi baru telah dibuat di https://enomsteams.z16.web.core.windows.net.</span>';
$string['meetingcreatedsuccess'] = 'Rapat "{$a}" berhasil dibuat!';
$string['meetingoptions'] = 'Pilihan rapat';
$string['meetingsapplink'] = 'Rapat URL Aplikasi';
$string['meetingsapplink_desc'] = 'Ini adalah URL lokasi pertemuan aplikasi';
$string['meetingurl'] = 'URL rapat Anda';
$string['openinnewwindow'] = 'Buka di jendela baru';
$string['pluginname'] = 'Rapat tim';
$string['privacy:metadata:msteamsapp'] = 'Pengaya Atto Teams Meeting tidak menyimpan data apa pun. Namun, pengaya ini mengirimkan kode bahasa pengguna ke aplikasi Microsoft Teams untuk menyediakan antarmuka pengguna berdasarkan bahasa pengguna.';
$string['privacy:metadata:msteamsapp:userlang'] = 'Kode bahasa pengguna dikirim ke aplikasi Microsoft Teams.';
$string['settings'] = 'Pengaturan rapat tim ..';
